@@ -1,4 +1,4 @@
-# $Id: install.py 1613 2016-12-10 20:25:33Z mwall $
+# $Id: install.py 1637 2016-12-25 04:41:41Z mwall $
 # installer for the forecast extension
 # Copyright 2014-2016 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.2.4",
+            version="3.2.6",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -65,12 +65,15 @@ class ForecastInstaller(ExtensionInstaller):
                     ['skins/forecast/skin.conf',
                      'skins/forecast/forecast.css',
                      'skins/forecast/forecast-periods.html.tmpl',
+                     'skins/forecast/forecast_compact.css',
+                     'skins/forecast/forecast_compact.inc',
                      'skins/forecast/forecast_iconic.css',
                      'skins/forecast/forecast_iconic.inc',
                      'skins/forecast/forecast_strip.css',
                      'skins/forecast/forecast_strip.inc',
                      'skins/forecast/forecast_table.css',
                      'skins/forecast/forecast_table.inc',
+                     'skins/forecast/compact.html.tmpl',
                      'skins/forecast/iconic.html.tmpl',
                      'skins/forecast/index.html.tmpl',
                      'skins/forecast/multiple-strips.html.tmpl',
